#!/bin/sh
# Reading config file
source /home/user/.config/ereswap/config

# Adjusting rcS-late to enable user's defined swap
# (or fall back to backup swap, in case of problems) and reset
# written-to-swap megabytes counter, both during boot.
sed -i "s@/sbin/swapon \-a || echo \"Failed to enable paging partition.\"@/sbin/swapon /dev/$swap0 \|\| /sbin/swapon /dev/$swap2\n      /usr/bin/iostat -md $swap0 \| grep $swap0 \| awk \'{print \$6}\' >/root/reswap.stat@g" /etc/event.d/rcS-late

# Huge thanks to Sc0rpius for help with (basically, creating) this script!